import smtplib
from email.mime.text import MIMEText
from email.utils import formatdate


class EmailSender:

    def __init__(self, host: str, port: int, is_ssl: bool = False, is_tls: bool = False, default_sender: str = None):
        self.default_sender = default_sender
        if is_ssl:
            self.smtp = smtplib.SMTP_SSL(host, port)
        else:
            self.smtp = smtplib.SMTP(host, port)
        if is_tls:
            self.smtp.starttls()

    def login(self, username: str, password: str):
        self.smtp.login(username, password)

    def send(self, to: str, subject: str, text: str, from_email: str = None):
        me = from_email if from_email else self.default_sender
        msg = MIMEText(text)
        msg['Subject'] = subject
        msg['From'] = me
        msg['To'] = to
        msg["Date"] = formatdate(localtime=True)
        self.smtp.sendmail(me, [to], msg.as_string())

    def close(self):
        self.smtp.quit()
