from abra_api.DataInfo import DataInfo


class IFilter:

    def __init__(self, config: dict):
        for required_config_key in self.required_config:
            if required_config_key not in config:
                raise ValueError('Config key {} not found in config'.format(required_config_key))
        self.config = config

    @property
    def required_config(self):
        raise NotImplementedError

    def is_handled(self, data_info: DataInfo) -> bool:
        """Does this filter handle this item?"""
        raise NotImplementedError

    def process(self, data_info: DataInfo) -> bool:
        """Process this data, we should get here only if is_handled returned True"""
        raise NotImplementedError

    def close(self) -> None:
        """Called when filter is not needed anymore"""
        raise NotImplementedError
